/*
 * FCKEmojiCommand Class resource file
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: en.js 770 2008-06-19 07:49:38Z fishbone $
 * @link       http://www.magic3.org
 */
FCKLang.EmojiEdit		            = "Edit Emoji";
FCKLang.EmojiInsert		            = "Insert Emoji";
FCKLang.EmojiInsertLbl		        = "Emoji";
FCKLang.EmojiDlgTitle		        = "Insert/Edit Emoji";
FCKLang.DlgPreviewImage				= "Preview";
FCKLang.DlgSelectImage				= "Selected";
FCKLang.EmojiBtn		            = "Insert/Edit Emoji";
